<?php
/**
 * ProWP functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage ProWP
 * @since ProWP 1.0
 */

if ( ! function_exists( 'prowp_support' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since ProWP 1.0
	 *
	 * @return void
	 */
	function prowp_support() {
		// Add support for Editor styles.
		add_theme_support( 'editor-styles' );

		// Remove core block patterns.
		remove_theme_support( 'core-block-patterns' );

		// Add dashboard functionality.
		include get_template_directory() . '/includes/dashboard/init.php';
	}
	endif;
add_action( 'after_setup_theme', 'prowp_support' );

if ( ! function_exists( 'prowp_enqueue_scripts' ) ) :
	/**
	 * Enqueue styles and scripts.
	 *
	 * @since ProWP 1.0
	 *
	 * @return void
	 */
	function prowp_enqueue_scripts() {
		// Determine if script debugging is enabled to decide if minified or full versions of the scripts and styles should be used.
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		// Register the base stylesheet with a handle of 'prowp-style' and provide its file URL, dependencies, and version.
		wp_register_style(
			'prowp-style',
			get_theme_file_uri( "assets/styles/template/core/global{$suffix}.css" ),
			array(),
			'1.7.1'
		);

		// Register the global JavaScript file with a handle, file URL, dependencies, version, and whether to load it in the footer.
		wp_register_script(
			'prowp-global-script',
			get_theme_file_uri( "/assets/scripts/public/global{$suffix}.js" ),
			array(),
			'1.0.0',
			false
		);

		// Similar to the global script, but this script is specifically for singular post pages.
		wp_register_script(
			'prowp-singular-post-script',
			get_theme_file_uri( "/assets/scripts/public/singular-post{$suffix}.js" ),
			array(),
			'1.0.0',
			false
		);

		// Registering another JavaScript file specifically for singular page views.
		wp_register_script(
			'prowp-singular-page-script',
			get_theme_file_uri( "/assets/scripts/public/singular-page{$suffix}.js" ),
			array(),
			'1.0.0',
			false
		);

		// Actually enqueue the registered stylesheet, making it active on the site.
		wp_enqueue_style( 'prowp-style' );

		// Enqueue the global script so it is included in the rendered HTML.
		wp_enqueue_script( 'prowp-global-script' );

		// Conditionally enqueue the singular post script if the current view is a singular post.
		if ( is_singular( 'post' ) ) {
			wp_enqueue_script( 'prowp-singular-post-script' );
		}

		// Similar to the post script, conditionally enqueue the page script if the current view is a singular page.
		if ( is_singular( 'page' ) ) {
			wp_enqueue_script( 'prowp-singular-page-script' );
		}
	}
	endif;
add_action( 'wp_enqueue_scripts', 'prowp_enqueue_scripts' );

if ( ! function_exists( 'prowp_enqueue_block_styles' ) ) :
	/**
	 * Enqueue individual block stylesheets.
	 */
	function prowp_enqueue_block_styles() {
		// Get all available block namespaces.
		$block_namespaces = glob( dirname( __FILE__ ) . '/assets/styles/blocks/*/' );
		$suffix           = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		$block_namespaces = array_map(
			function( $type_path ) {
				return basename( $type_path );
			},
			$block_namespaces
		);

		foreach ( $block_namespaces as $block_namespace ) {

			// Get all available block styles of the given block namespace.
			$block_styles = glob( dirname( __FILE__ ) . '/assets/styles/blocks/' . $block_namespace . '/*.css' );

			$block_styles = array_reduce(
				$block_styles,
				function( $carry, $styles_path ) {
					$basename = basename( $styles_path, '.css' );
					// Check if $basename has .min in its name.
					if ( strpos( $basename, '.min' ) === false ) {
						$carry[] = $basename;
					}
					return $carry;
				},
				array()
			);

			foreach ( $block_styles as $block_style ) {
				// Enqueue individual block stylesheets.
				wp_enqueue_block_style(
					$block_namespace . '/' . $block_style,
					array(
						'handle' => 'prowp-' . $block_namespace . '-' . $block_style . '-styles',
						'src'    => get_theme_file_uri( 'assets/styles/blocks/' . $block_namespace . '/' . $block_style . "{$suffix}.css" ),
						'path'   => get_theme_file_path( 'assets/styles/blocks/' . $block_namespace . '/' . $block_style . '.css' ),
					)
				);
			}
		}
	}
	endif;
add_action( 'after_setup_theme', 'prowp_enqueue_block_styles' );

if ( ! function_exists( 'prowp_enqueue_block_assets' ) ) :
	/**
	 * Register Block editor styles.
	 */
	function prowp_enqueue_block_assets() {
		// Make sure to use allt these styles in editor.
		if ( ! is_admin() ) {
			return;
		}

		// Determine if script debugging is enabled to decide if minified or full versions of the scripts and styles should be used.
		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		// Register theme editor styles.
		wp_register_style(
			'prowp-block-editor-style',
			get_theme_file_uri( "/assets/styles/editor/core/global{$suffix}.css" ),
			array(),
			'1.8.1'
		);

		// Enqueue theme editor styles.
		wp_enqueue_style( 'prowp-block-editor-style' );
	}
	endif;
add_action( 'enqueue_block_assets', 'prowp_enqueue_block_assets' );

if ( ! function_exists( 'prowp_register_block_styles' ) ) :
	/**
	 * Register Block Styles.
	 */
	function prowp_register_block_styles() {
		// List: Unstyled.
		register_block_style( // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style
			'core/list',
			array(
				'name'         => 'th-unstyled-list',
				'label'        => esc_html__( 'Unstyled', 'prowp' ),
				'inline_style' => '.is-style-th-unstyled-list { list-style: none; padding-inline-start: 0; }',
			)
		);

		// List: Highlighted marker.
		register_block_style( // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style
			'core/list',
			array(
				'name'         => 'th-highlight-marker',
				'label'        => esc_html__( 'Highlighted marker', 'prowp' ),
				'inline_style' => '.is-style-th-highlight-marker {padding-inline-end: 1.5em;}.is-style-th-highlight-marker li + li {border-block-start: 1px dashed var(--wp--preset--color--tertiary);margin-block-start: 0.4em;padding-block-start: 0.45em;}.has-background .is-style-th-highlight-marker li + li {border-block-start-color: rgba(0,0,0,0.25);}.is-style-th-highlight-marker li {position: relative;z-index: 1;padding-inline: 0.5em;}.is-style-th-highlight-marker li::before {content: "";width: 1.175em;height: 1.15em;background-color: var(--wp--preset--color--contrast);position: absolute;margin-block-start: 0.15em;left: -1.25em;z-index: -1;}.has-background .is-style-th-highlight-marker li::before {background-color: rgba(0,0,0,0.2);}.is-style-th-highlight-marker li::marker {color: var(--wp--preset--color--base);font-size: 0.79em;font-weight: bold;}.has-background .is-style-th-highlight-marker li::marker {color: currentColor;}.is-style-th-highlight-marker li ul {padding-block: 0.15em }.is-style-th-highlight-marker li ul li::before {background-color: var(--wp--preset--color--secondary);}.has-background .is-style-th-highlight-marker li ul li::before {opacity: 0.75;}.is-style-th-highlight-marker li ul {list-style-type:disc;}',
			)
		);

		// List: Inline with bordered items.
		register_block_style( // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style
			'core/list',
			array(
				'name'         => 'th-inline-bordered',
				'label'        => esc_html__( 'Inline and bordered items', 'prowp' ),
				'inline_style' => '.is-style-th-inline-bordered {list-style: none;padding-inline: 0;display: flex;flex-wrap: wrap;gap: 0.5em;}.is-style-th-inline-bordered li {border: 1px solid;padding: 0.2em 0.8em;border-radius: 1em;}',
			)
		);

		// Image: Frame with shadow.
		register_block_style( // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style
			'core/image',
			array(
				'name'         => 'th-frame-shadow',
				'label'        => esc_html__( 'Frame with shadow', 'prowp' ),
				'inline_style' => '.is-style-th-frame-shadow img { border: 3px solid var(--wp--preset--color--white); box-shadow: 3px 3px 0 0 var(--wp--preset--color--tertiary), -0.5px -0.5px 9px 0 var(--wp--preset--color--tertiary); }',
			)
		);

		// Image: Frame with shadow.
		register_block_style( // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style
			'core/post-featured-image',
			array(
				'name'         => 'th-frame-shadow',
				'label'        => esc_html__( 'Frame with shadow', 'prowp' ),
				'inline_style' => '.is-style-th-frame-shadow img { border: 3px solid var(--wp--preset--color--white); box-shadow: 3px 3px 0 0 var(--wp--preset--color--tertiary), -0.5px -0.5px 9px 0 var(--wp--preset--color--tertiary); }',
			)
		);
	}
	endif;
add_action( 'init', 'prowp_register_block_styles' );
