<?php
/**
 * Build our admin dashboard.
 *
 * @package coala-onboarding
 */

namespace CO;

/**
 * Exit if the file is accessed directly.
 *
 * This is a security feature to make sure that
 * the file cannot be accessed unless it is included or required by another file,
 * ensuring that it is always executed in the proper context.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * This class adds HTML attributes to various theme elements.
 */
class Dashboard {
	/**
	 * Class instance.
	 *
	 * @var $instance Class instance.
	 */
	private static $instance;

	/**
	 * Menu slug.
	 *
	 * @var $menu_slug string
	 */
	private static $menu_slug = 'co-dashboard';

	/**
	 * Initiator.
	 */
	public static function get_instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Get started.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'add_menu_item' ) );
		add_filter( 'admin_body_class', array( $this, 'set_admin_body_class' ) );
		add_action( 'in_admin_header', array( $this, 'add_header' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		add_action( 'co_admin_dashboard', array( $this, 'dashboard_theme_customization' ) );
	}

	/**
	 * Adds dashboard menu item.
	 */
	public function add_menu_item() {
		add_theme_page(
			esc_html__( 'ProWP', 'prowp' ),
			esc_html__( 'ProWP', 'prowp' ),
			'edit_theme_options',
			self::$menu_slug,
			array( $this, 'page' )
		);
	}

	/**
	 * Returns available dashboard pages.
	 */
	public static function get_pages() {
		$screen_slug = 'appearance_page_' . self::$menu_slug;

		return apply_filters(
			'co_dashboard_screens',
			array( $screen_slug )
		);
	}

	/**
	 * Adds a body class on dashboard pages.
	 *
	 * @param string $classes The existing classes.
	 */
	public function set_admin_body_class( $classes ) {
		$dashboard_pages = self::get_pages();
		$current_screen  = get_current_screen();

		if ( in_array( $current_screen->id, $dashboard_pages, true ) ) {
			$classes .= ' co-dashboard-page';
		}

		return $classes;
	}

	/**
	 * Ouputs dashboard header.
	 */
	public static function header() {
		?>
		<div class="co-dashboard-header">
			<div class="co-dashboard-header__title">
				<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
			</div>

			<?php self::navigation(); ?>
		</div>
		<?php
	}

	/**
	 * Outputs dashboard navigation.
	 */
	public static function navigation() {
		$screen_slug         = 'appearance_page_' . self::$menu_slug;
		$dashboard_admin_url = 'themes.php?page=' . self::$menu_slug;
		$screen              = get_current_screen();
		$tabs                = apply_filters(
			'co_dashboard_tabs',
			array(
				'dashboard' => array(
					'name'  => esc_html__( 'Dashboard', 'prowp' ),
					'url'   => admin_url( $dashboard_admin_url ),
					'class' => $screen_slug === $screen->id ? 'active' : '',
				),
				'support'   => array(
					'name'     => esc_html__( 'Support', 'prowp' ),
					'url'      => 'https://wordpress.org/support/theme/prowp/',
					'class'    => '',
					'external' => true,
				),
			)
		);
		?>

		<div class="co-dashboard-header__navigation">
			<?php
			foreach ( $tabs as $tab ) {
				if ( isset( $tab['class'] ) && '' !== $tab['class'] ) {
					printf(
						'<a href="%1$s" class="%2$s" %4$s>%3$s</a>',
						esc_url( $tab['url'] ),
						esc_attr( $tab['class'] ),
						esc_html( $tab['name'] ),
						! empty( $tab['external'] ) ? 'target="_blank" rel="noreferrer noopener"' : ''
					);
				} else {
					printf(
						'<a href="%1$s" %2$s>%3$s</a>',
						esc_url( $tab['url'] ),
						! empty( $tab['external'] ) ? 'target="_blank" rel="noreferrer noopener"' : '',
						esc_html( $tab['name'] ),
					);
				}
			}
			?>
		</div>
		<?php
	}

	/**
	 * Adds dashboard header.
	 */
	public function add_header() {
		$dashboard_pages = self::get_pages();
		$current_screen  = get_current_screen();

		if ( in_array( $current_screen->id, $dashboard_pages, true ) ) {
			self::header();
		}
	}

	/**
	 * Adds scripts to the page.
	 */
	public function enqueue_scripts() {
		$dashboard_pages = self::get_pages();
		$current_screen  = get_current_screen();

		// Load scripts only when it is needed.
		if ( ! in_array( $current_screen->id, $dashboard_pages, true ) ) {
			return;
		}

		// Register the base stylesheet with a handle of 'co-admin-dashboard' and provide its file URL, dependencies, and version.
		wp_register_style(
			'co-admin-dashboard',
			CO_DASHBOARD_URL . '/assets/styles/dashboard.css',
			array(),
			'0.0.1',
		);

		wp_enqueue_style( 'co-admin-dashboard' );
	}

	/**
	 * Outputs HTML for dashboard page.
	 */
	public function page() {
		?>
		<div class="wrap">
			<div class="co-dashboard">
				<?php do_action( 'co_admin_dashboard' ); ?>
			</div>
		</div>
		<?php
	}

	/**
	 * Ouput container for theme customization section.
	 */
	public function dashboard_theme_customization() {
		// Define the base URLs and arguments
		$base_editor_url           = admin_url( 'site-editor.php' );
		$base_new_post_url         = admin_url( 'post-new.php' );
		$base_reading_settings_url = admin_url( 'options-reading.php' );

		$editor_header_args = array(
			'postId'   => 'prowp//header-default',
			'postType' => 'wp_template_part',
		);

		$editor_color_scheme_args = array(
			'canvas' => 'edit',
		);

		$new_page_url_args = array(
			'post_type' => 'page',
		);

		// Create the customization URLs.
		$branding_url         = add_query_arg( $editor_header_args, $base_editor_url );
		$color_scheme_url     = add_query_arg( $editor_color_scheme_args, $base_editor_url );
		$layout_designs_url   = add_query_arg( $new_page_url_args, $base_new_post_url );
		$reading_settings_url = $base_reading_settings_url;  // No additional arguments are added here

		// Create sections.
		$sections = array(
			array(
				'title'       => esc_html__( 'Branding', 'prowp' ),
				'description' => esc_html__( 'Define your site title, description, logo, and primary navigation.', 'prowp' ),
				'actions'     => array(
					'customize' => array(
						'label' => esc_html__( 'Start Customizing', 'prowp' ),
						'url'   => $branding_url,
					),
					'learn'     => array(
						'label' => esc_html__( 'Learn More', 'prowp' ),
						'url'   => 'https://prowp.themesharbor.com/documentation/branding-customization/',
					),
				),
			),

			array(
				'title'       => esc_html__( 'Color Scheme', 'prowp' ),
				'description' => esc_html__( 'Establish your global colors to align your site with your brand identity.', 'prowp' ),
				'actions'     => array(
					'customize' => array(
						'label' => esc_html__( 'Start Customizing', 'prowp' ),
						'url'   => $color_scheme_url,
					),
					'learn'     => array(
						'label' => esc_html__( 'Learn More', 'prowp' ),
						'url'   => 'https://prowp.themesharbor.com/documentation/color-scheme-customization/',
					),
				),
			),

			array(
				'title'       => esc_html__( 'Layout Designs', 'prowp' ),
				'description' => esc_html__( 'Choose from pre-designed layouts when creating a new page.', 'prowp' ),
				'actions'     => array(
					'customize' => array(
						'label' => esc_html__( 'Start Customizing', 'prowp' ),
						'url'   => $layout_designs_url,
					),
					'learn'     => array(
						'label' => esc_html__( 'Learn More', 'prowp' ),
						'url'   => 'https://prowp.themesharbor.com/documentation/layout-designs-customization/',
					),
				),
			),

			array(
				'title'       => esc_html__( 'Home & Blog Settings', 'prowp' ),
				'description' => esc_html__( 'Specify your homepage and blog page selections.', 'prowp' ),
				'actions'     => array(
					'customize' => array(
						'label' => esc_html__( 'Start Customizing', 'prowp' ),
						'url'   => $reading_settings_url,
					),
					'learn'     => array(
						'label' => esc_html__( 'Learn More', 'prowp' ),
						'url'   => 'https://prowp.themesharbor.com/documentation/home-blog-settings-customization/',
					),
				),
			),
		);
		?>

		<h2 class="section-title">
			<?php esc_html_e( 'Theme Customization', 'prowp' ); ?>
		</h2>
		<p>
			<?php esc_html_e( 'ProWP is a WordPress block theme with full site editing support.', 'prowp' ); ?>
		</p>

		<ul class="guide-list">
		<?php
		foreach ( $sections as $section ) :
			?>
			<li>
				<h3 class="sub-title">
					<?php echo esc_html( $section['title'] ); ?>
				</h3>
				<p>
					<?php echo esc_html( $section['description'] ); ?>
				</p>
				<p>
					<a class="customization-action" href="<?php echo esc_url( $section['actions']['customize']['url'] ); ?>"><?php echo esc_html( $section['actions']['customize']['label'] ); ?></a>
					<span class="sep">|</span>
					<a class="learn-action" href="<?php echo esc_url( $section['actions']['learn']['url'] ); ?>" target="_blank"><?php echo esc_html( $section['actions']['learn']['label'] ); ?></a>
				</p>
			</li>
			<?php
			endforeach;
		?>
		</ul>
		<?php
	}
}
